@@ -89,10 +89,10 @@ struct activity cpu_act = {
 	.f_raw_print	= raw_print_cpu_stats,
 	.f_pcp_print	= pcp_print_cpu_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "CPU utilization",
 #endif
 	.name		= "A_CPU",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 1,
 	.nr_ini		= -1,
@@ -100,10 +100,15 @@ struct activity cpu_act = {
 	.nr_max		= NR_CPUS + 1,
 	.nr		= {-1, -1, -1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_CPU_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_CPU_SIZE,
 	.msize		= STATS_CPU_SIZE,
 	.opt_flags	= AO_F_CPU_DEF,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= &cpu_bitmap
 };
 
@@ -135,10 +140,10 @@ struct activity pcsw_act = {
 	.f_raw_print	= raw_print_pcsw_stats,
 	.f_pcp_print	= pcp_print_pcsw_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "Task creation and switching activity",
 #endif
 	.name		= "A_PCSW",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 2,
 	.nr_ini		= 1,
@@ -146,10 +151,15 @@ struct activity pcsw_act = {
 	.nr_max		= 1,
 	.nr		= {1, 1, 1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_PCSW_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_PCSW_SIZE,
 	.msize		= STATS_PCSW_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -181,10 +191,10 @@ struct activity irq_act = {
 	.f_raw_print	= raw_print_irq_stats,
 	.f_pcp_print	= pcp_print_irq_stats,
 	.f_count_new	= count_new_int,
-	.item_list	= NULL,
 	.desc		= "Interrupts statistics",
 #endif
 	.name		= "A_IRQ",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 0,
 	.nr_ini		= -1,
@@ -192,10 +202,15 @@ struct activity irq_act = {
 	.nr_max		= NR_CPUS + 1,
 	.nr		= {-1, -1, -1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_IRQ_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_IRQ_SIZE,
 	.msize		= STATS_IRQ_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= &cpu_bitmap
 };
 
@@ -227,10 +242,10 @@ struct activity swap_act = {
 	.f_raw_print	= raw_print_swap_stats,
 	.f_pcp_print	= pcp_print_swap_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "Swap activity",
 #endif
 	.name		= "A_SWAP",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 1,
 	.nr_ini		= 1,
@@ -238,10 +253,15 @@ struct activity swap_act = {
 	.nr_max		= 1,
 	.nr		= {1, 1, 1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_SWAP_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_SWAP_SIZE,
 	.msize		= STATS_SWAP_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -274,10 +294,10 @@ struct activity paging_act = {
 	.f_raw_print	= raw_print_paging_stats,
 	.f_pcp_print	= pcp_print_paging_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "Paging activity",
 #endif
 	.name		= "A_PAGE",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 3,
 	.nr_ini		= 1,
@@ -285,10 +305,15 @@ struct activity paging_act = {
 	.nr_max		= 1,
 	.nr		= {1, 1, 1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_PAGING_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_PAGING_SIZE,
 	.msize		= STATS_PAGING_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -320,10 +345,10 @@ struct activity io_act = {
 	.f_raw_print	= raw_print_io_stats,
 	.f_pcp_print	= pcp_print_io_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "I/O and transfer rate statistics",
 #endif
 	.name		= "A_IO",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 2,
 	.nr_ini		= 1,
@@ -331,10 +356,15 @@ struct activity io_act = {
 	.nr_max		= 1,
 	.nr		= {1, 1, 1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_IO_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_IO_SIZE,
 	.msize		= STATS_IO_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -367,10 +397,10 @@ struct activity memory_act = {
 	.f_raw_print	= raw_print_memory_stats,
 	.f_pcp_print	= pcp_print_memory_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "Memory and/or swap utilization",
 #endif
 	.name		= "A_MEMORY",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 9,
 	.nr_ini		= 1,
@@ -378,10 +408,15 @@ struct activity memory_act = {
 	.nr_max		= 1,
 	.nr		= {1, 1, 1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_MEMORY_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_MEMORY_SIZE,
 	.msize		= STATS_MEMORY_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -413,10 +448,10 @@ struct activity ktables_act = {
 	.f_raw_print	= raw_print_ktables_stats,
 	.f_pcp_print	= pcp_print_ktables_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "Kernel tables statistics",
 #endif
 	.name		= "A_KTABLES",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 2,
 	.nr_ini		= 1,
@@ -424,10 +459,15 @@ struct activity ktables_act = {
 	.nr_max		= 1,
 	.nr		= {1, 1, 1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_KTABLES_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_KTABLES_SIZE,
 	.msize		= STATS_KTABLES_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -459,10 +499,10 @@ struct activity queue_act = {
 	.f_raw_print	= raw_print_queue_stats,
 	.f_pcp_print	= pcp_print_queue_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "Queue length and load average statistics",
 #endif
 	.name		= "A_QUEUE",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 3,
 	.nr_ini		= 1,
@@ -470,10 +510,15 @@ struct activity queue_act = {
 	.nr_max		= 1,
 	.nr		= {1, 1, 1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_QUEUE_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_QUEUE_SIZE,
 	.msize		= STATS_QUEUE_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -505,10 +550,10 @@ struct activity serial_act = {
 	.f_raw_print	= raw_print_serial_stats,
 	.f_pcp_print	= pcp_print_serial_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "TTY devices statistics",
 #endif
 	.name		= "A_SERIAL",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 0,
 	.nr_ini		= -1,
@@ -516,10 +561,15 @@ struct activity serial_act = {
 	.nr_max		= MAX_NR_SERIAL_LINES,
 	.nr		= {-1, -1, -1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_SERIAL_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_SERIAL_SIZE,
 	.msize		= STATS_SERIAL_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -551,10 +601,10 @@ struct activity disk_act = {
 	.f_raw_print	= raw_print_disk_stats,
 	.f_pcp_print	= pcp_print_disk_stats,
 	.f_count_new	= count_new_disk,
-	.item_list	= NULL,
 	.desc		= "Block devices statistics",
 #endif
 	.name		= "A_DISK",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 5,
 	.nr_ini		= -1,
@@ -562,10 +612,15 @@ struct activity disk_act = {
 	.nr_max		= MAX_NR_DISKS,
 	.nr		= {-1, -1, -1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_DISK_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_DISK_SIZE,
 	.msize		= STATS_DISK_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -597,10 +652,10 @@ struct activity net_dev_act = {
 	.f_raw_print	= raw_print_net_dev_stats,
 	.f_pcp_print	= pcp_print_net_dev_stats,
 	.f_count_new	= count_new_net_dev,
-	.item_list	= NULL,
 	.desc		= "Network interfaces statistics",
 #endif
 	.name		= "A_NET_DEV",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 4,
 	.nr_ini		= -1,
@@ -608,10 +663,15 @@ struct activity net_dev_act = {
 	.nr_max		= MAX_NR_IFACES,
 	.nr		= {-1, -1, -1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_NET_DEV_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_NET_DEV_SIZE,
 	.msize		= STATS_NET_DEV_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -644,10 +704,10 @@ struct activity net_edev_act = {
 	.f_raw_print	= raw_print_net_edev_stats,
 	.f_pcp_print	= pcp_print_net_edev_stats,
 	.f_count_new	= count_new_net_edev,
-	.item_list	= NULL,
 	.desc		= "Network interfaces errors statistics",
 #endif
 	.name		= "A_NET_EDEV",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 4,
 	.nr_ini		= -1,
@@ -655,10 +715,15 @@ struct activity net_edev_act = {
 	.nr_max		= MAX_NR_IFACES,
 	.nr		= {-1, -1, -1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_NET_EDEV_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_NET_EDEV_SIZE,
 	.msize		= STATS_NET_EDEV_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -690,10 +755,10 @@ struct activity net_nfs_act = {
 	.f_raw_print	= raw_print_net_nfs_stats,
 	.f_pcp_print	= pcp_print_net_nfs_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "NFS client statistics",
 #endif
 	.name		= "A_NET_NFS",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 3,
 	.nr_ini		= 1,
@@ -701,10 +766,15 @@ struct activity net_nfs_act = {
 	.nr_max		= 1,
 	.nr		= {1, 1, 1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_NET_NFS_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_NET_NFS_SIZE,
 	.msize		= STATS_NET_NFS_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -737,10 +807,10 @@ struct activity net_nfsd_act = {
 	.f_raw_print	= raw_print_net_nfsd_stats,
 	.f_pcp_print	= pcp_print_net_nfsd_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "NFS server statistics",
 #endif
 	.name		= "A_NET_NFSD",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 5,
 	.nr_ini		= 1,
@@ -748,10 +818,15 @@ struct activity net_nfsd_act = {
 	.nr_max		= 1,
 	.nr		= {1, 1, 1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_NET_NFSD_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_NET_NFSD_SIZE,
 	.msize		= STATS_NET_NFSD_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -783,10 +858,10 @@ struct activity net_sock_act = {
 	.f_raw_print	= raw_print_net_sock_stats,
 	.f_pcp_print	= pcp_print_net_sock_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "IPv4 sockets statistics",
 #endif
 	.name		= "A_NET_SOCK",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 2,
 	.nr_ini		= 1,
@@ -794,10 +869,15 @@ struct activity net_sock_act = {
 	.nr_max		= 1,
 	.nr		= {1, 1, 1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_NET_SOCK_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_NET_SOCK_SIZE,
 	.msize		= STATS_NET_SOCK_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -829,10 +909,10 @@ struct activity net_ip_act = {
 	.f_raw_print	= raw_print_net_ip_stats,
 	.f_pcp_print	= pcp_print_net_ip_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "IPv4 traffic statistics",
 #endif
 	.name		= "A_NET_IP",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 3,
 	.nr_ini		= 1,
@@ -840,10 +920,15 @@ struct activity net_ip_act = {
 	.nr_max		= 1,
 	.nr		= {1, 1, 1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_NET_IP_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_NET_IP_SIZE,
 	.msize		= STATS_NET_IP_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -875,10 +960,10 @@ struct activity net_eip_act = {
 	.f_raw_print	= raw_print_net_eip_stats,
 	.f_pcp_print	= pcp_print_net_eip_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "IPv4 traffic errors statistics",
 #endif
 	.name		= "A_NET_EIP",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 3,
 	.nr_ini		= 1,
@@ -886,10 +971,15 @@ struct activity net_eip_act = {
 	.nr_max		= 1,
 	.nr		= {1, 1, 1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_NET_EIP_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_NET_EIP_SIZE,
 	.msize		= STATS_NET_EIP_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -922,10 +1012,10 @@ struct activity net_icmp_act = {
 	.f_raw_print	= raw_print_net_icmp_stats,
 	.f_pcp_print	= pcp_print_net_icmp_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "ICMPv4 traffic statistics",
 #endif
 	.name		= "A_NET_ICMP",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 4,
 	.nr_ini		= 1,
@@ -933,10 +1023,15 @@ struct activity net_icmp_act = {
 	.nr_max		= 1,
 	.nr		= {1, 1, 1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_NET_ICMP_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_NET_ICMP_SIZE,
 	.msize		= STATS_NET_ICMP_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -969,10 +1064,10 @@ struct activity net_eicmp_act = {
 	.f_raw_print	= raw_print_net_eicmp_stats,
 	.f_pcp_print	= pcp_print_net_eicmp_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "ICMPv4 traffic errors statistics",
 #endif
 	.name		= "A_NET_EICMP",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 6,
 	.nr_ini		= 1,
@@ -980,10 +1075,15 @@ struct activity net_eicmp_act = {
 	.nr_max		= 1,
 	.nr		= {1, 1, 1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_NET_EICMP_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_NET_EICMP_SIZE,
 	.msize		= STATS_NET_EICMP_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -1015,10 +1115,10 @@ struct activity net_tcp_act = {
 	.f_raw_print	= raw_print_net_tcp_stats,
 	.f_pcp_print	= pcp_print_net_tcp_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "TCPv4 traffic statistics",
 #endif
 	.name		= "A_NET_TCP",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 2,
 	.nr_ini		= 1,
@@ -1026,10 +1126,15 @@ struct activity net_tcp_act = {
 	.nr_max		= 1,
 	.nr		= {1, 1, 1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_NET_TCP_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_NET_TCP_SIZE,
 	.msize		= STATS_NET_TCP_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -1061,10 +1166,10 @@ struct activity net_etcp_act = {
 	.f_raw_print	= raw_print_net_etcp_stats,
 	.f_pcp_print	= pcp_print_net_etcp_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "TCPv4 traffic errors statistics",
 #endif
 	.name		= "A_NET_ETCP",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 2,
 	.nr_ini		= 1,
@@ -1072,10 +1177,15 @@ struct activity net_etcp_act = {
 	.nr_max		= 1,
 	.nr		= {1, 1, 1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_NET_ETCP_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_NET_ETCP_SIZE,
 	.msize		= STATS_NET_ETCP_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -1107,10 +1217,10 @@ struct activity net_udp_act = {
 	.f_raw_print	= raw_print_net_udp_stats,
 	.f_pcp_print	= pcp_print_net_udp_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "UDPv4 traffic statistics",
 #endif
 	.name		= "A_NET_UDP",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 2,
 	.nr_ini		= 1,
@@ -1118,10 +1228,15 @@ struct activity net_udp_act = {
 	.nr_max		= 1,
 	.nr		= {1, 1, 1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_NET_UDP_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_NET_UDP_SIZE,
 	.msize		= STATS_NET_UDP_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -1153,10 +1268,10 @@ struct activity net_sock6_act = {
 	.f_raw_print	= raw_print_net_sock6_stats,
 	.f_pcp_print	= pcp_print_net_sock6_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "IPv6 sockets statistics",
 #endif
 	.name		= "A_NET_SOCK6",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 1,
 	.nr_ini		= 1,
@@ -1164,10 +1279,15 @@ struct activity net_sock6_act = {
 	.nr_max		= 1,
 	.nr		= {1, 1, 1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_NET_SOCK6_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_NET_SOCK6_SIZE,
 	.msize		= STATS_NET_SOCK6_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -1200,10 +1320,10 @@ struct activity net_ip6_act = {
 	.f_raw_print	= raw_print_net_ip6_stats,
 	.f_pcp_print	= pcp_print_net_ip6_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "IPv6 traffic statistics",
 #endif
 	.name		= "A_NET_IP6",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 4,
 	.nr_ini		= 1,
@@ -1211,10 +1331,15 @@ struct activity net_ip6_act = {
 	.nr_max		= 1,
 	.nr		= {1, 1, 1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_NET_IP6_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_NET_IP6_SIZE,
 	.msize		= STATS_NET_IP6_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -1247,10 +1372,10 @@ struct activity net_eip6_act = {
 	.f_raw_print	= raw_print_net_eip6_stats,
 	.f_pcp_print	= pcp_print_net_eip6_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "IPv6 traffic errors statistics",
 #endif
 	.name		= "A_NET_EIP6",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 4,
 	.nr_ini		= 1,
@@ -1258,10 +1383,15 @@ struct activity net_eip6_act = {
 	.nr_max		= 1,
 	.nr		= {1, 1, 1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_NET_EIP6_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_NET_EIP6_SIZE,
 	.msize		= STATS_NET_EIP6_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -1295,10 +1425,10 @@ struct activity net_icmp6_act = {
 	.f_raw_print	= raw_print_net_icmp6_stats,
 	.f_pcp_print	= pcp_print_net_icmp6_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "ICMPv6 traffic statistics",
 #endif
 	.name		= "A_NET_ICMP6",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 5,
 	.nr_ini		= 1,
@@ -1306,10 +1436,15 @@ struct activity net_icmp6_act = {
 	.nr_max		= 1,
 	.nr		= {1, 1, 1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_NET_ICMP6_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_NET_ICMP6_SIZE,
 	.msize		= STATS_NET_ICMP6_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -1342,10 +1477,10 @@ struct activity net_eicmp6_act = {
 	.f_raw_print	= raw_print_net_eicmp6_stats,
 	.f_pcp_print	= pcp_print_net_eicmp6_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "ICMPv6 traffic errors statistics",
 #endif
 	.name		= "A_NET_EICMP6",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 6,
 	.nr_ini		= 1,
@@ -1353,10 +1488,15 @@ struct activity net_eicmp6_act = {
 	.nr_max		= 1,
 	.nr		= {1, 1, 1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_NET_EICMP6_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_NET_EICMP6_SIZE,
 	.msize		= STATS_NET_EICMP6_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -1388,10 +1528,10 @@ struct activity net_udp6_act = {
 	.f_raw_print	= raw_print_net_udp6_stats,
 	.f_pcp_print	= pcp_print_net_udp6_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "UDPv6 traffic statistics",
 #endif
 	.name		= "A_NET_UDP6",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 2,
 	.nr_ini		= 1,
@@ -1399,10 +1539,15 @@ struct activity net_udp6_act = {
 	.nr_max		= 1,
 	.nr		= {1, 1, 1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_NET_UDP6_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_NET_UDP6_SIZE,
 	.msize		= STATS_NET_UDP6_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -1434,10 +1579,10 @@ struct activity pwr_cpufreq_act = {
 	.f_raw_print	= raw_print_pwr_cpufreq_stats,
 	.f_pcp_print	= pcp_print_pwr_cpufreq_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "CPU clock frequency",
 #endif
 	.name		= "A_PWR_CPU",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 1,
 	.nr_ini		= -1,
@@ -1445,10 +1590,15 @@ struct activity pwr_cpufreq_act = {
 	.nr_max		= NR_CPUS + 1,
 	.nr		= {-1, -1, -1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_PWR_CPUFREQ_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_PWR_CPUFREQ_SIZE,
 	.msize		= STATS_PWR_CPUFREQ_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= &cpu_bitmap
 };
 
@@ -1480,10 +1630,10 @@ struct activity pwr_fan_act = {
 	.f_raw_print	= raw_print_pwr_fan_stats,
 	.f_pcp_print	= pcp_print_pwr_fan_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "Fans speed",
 #endif
 	.name		= "A_PWR_FAN",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 1,
 	.nr_ini		= -1,
@@ -1491,10 +1641,15 @@ struct activity pwr_fan_act = {
 	.nr_max		= MAX_NR_FANS,
 	.nr		= {-1, -1, -1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_PWR_FAN_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_PWR_FAN_SIZE,
 	.msize		= STATS_PWR_FAN_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -1526,10 +1681,10 @@ struct activity pwr_temp_act = {
 	.f_raw_print	= raw_print_pwr_temp_stats,
 	.f_pcp_print	= pcp_print_pwr_temp_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "Devices temperature",
 #endif
 	.name		= "A_PWR_TEMP",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 2,
 	.nr_ini		= -1,
@@ -1537,10 +1692,15 @@ struct activity pwr_temp_act = {
 	.nr_max		= MAX_NR_TEMP_SENSORS,
 	.nr		= {-1, -1, -1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_PWR_TEMP_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_PWR_TEMP_SIZE,
 	.msize		= STATS_PWR_TEMP_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -1572,10 +1732,10 @@ struct activity pwr_in_act = {
 	.f_raw_print	= raw_print_pwr_in_stats,
 	.f_pcp_print	= pcp_print_pwr_in_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "Voltage inputs statistics",
 #endif
 	.name		= "A_PWR_IN",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 2,
 	.nr_ini		= -1,
@@ -1583,10 +1743,15 @@ struct activity pwr_in_act = {
 	.nr_max		= MAX_NR_IN_SENSORS,
 	.nr		= {-1, -1, -1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_PWR_IN_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_PWR_IN_SIZE,
 	.msize		= STATS_PWR_IN_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -1618,10 +1783,10 @@ struct activity huge_act = {
 	.f_raw_print	= raw_print_huge_stats,
 	.f_pcp_print	= pcp_print_huge_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "Huge pages utilization",
 #endif
 	.name		= "A_HUGE",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 2,
 	.nr_ini		= 1,
@@ -1629,10 +1794,15 @@ struct activity huge_act = {
 	.nr_max		= 1,
 	.nr		= {1, 1, 1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_HUGE_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_HUGE_SIZE,
 	.msize		= STATS_HUGE_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -1663,10 +1833,10 @@ struct activity pwr_wghfreq_act = {
 	.f_svg_print	= NULL,
 	.f_raw_print	= raw_print_pwr_wghfreq_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "CPU weighted frequency",
 #endif
 	.name		= "A_PWR_FREQ",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 0,
 	.nr_ini		= -1,
@@ -1674,10 +1844,15 @@ struct activity pwr_wghfreq_act = {
 	.nr_max		= NR_CPUS + 1,
 	.nr		= {-1, -1, -1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_PWR_WGHFREQ_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_PWR_WGHFREQ_SIZE,
 	.msize		= STATS_PWR_WGHFREQ_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= &cpu_bitmap
 };
 
@@ -1709,10 +1884,10 @@ struct activity pwr_usb_act = {
 	.f_raw_print	= raw_print_pwr_usb_stats,
 	.f_pcp_print	= pcp_print_pwr_usb_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "USB devices",
 #endif
 	.name		= "A_PWR_USB",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 0,
 	.nr_ini		= -1,
@@ -1720,10 +1895,15 @@ struct activity pwr_usb_act = {
 	.nr_max		= MAX_NR_USB,
 	.nr		= {-1, -1, -1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_PWR_USB_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_PWR_USB_SIZE,
 	.msize		= STATS_PWR_USB_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -1756,10 +1936,10 @@ struct activity filesystem_act = {
 	.f_raw_print	= raw_print_filesystem_stats,
 	.f_pcp_print	= pcp_print_filesystem_stats,
 	.f_count_new	= count_new_filesystem,
-	.item_list	= NULL,
 	.desc		= "Filesystems statistics",
 #endif
 	.name		= "A_FS",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 4,
 	.nr_ini		= -1,
@@ -1767,10 +1947,15 @@ struct activity filesystem_act = {
 	.nr_max		= MAX_NR_FS,
 	.nr		= {-1, -1, -1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_FILESYSTEM_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_FILESYSTEM_SIZE,
 	.msize		= STATS_FILESYSTEM_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -1802,10 +1987,10 @@ struct activity fchost_act = {
 	.f_raw_print	= raw_print_fchost_stats,
 	.f_pcp_print	= pcp_print_fchost_stats,
 	.f_count_new	= count_new_fchost,
-	.item_list	= NULL,
 	.desc		= "Fibre Channel HBA statistics",
 #endif
 	.name		= "A_NET_FC",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 2,
 	.nr_ini		= -1,
@@ -1813,10 +1998,15 @@ struct activity fchost_act = {
 	.nr_max		= MAX_NR_FCHOSTS,
 	.nr		= {-1, -1, -1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_FCHOST_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_FCHOST_SIZE,
 	.msize		= STATS_FCHOST_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -1849,10 +2039,10 @@ struct activity softnet_act = {
 	.f_raw_print	= raw_print_softnet_stats,
 	.f_pcp_print	= pcp_print_softnet_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "Software-based network processing statistics",
 #endif
 	.name		= "A_NET_SOFT",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 3,
 	.nr_ini		= -1,
@@ -1860,10 +2050,15 @@ struct activity softnet_act = {
 	.nr_max		= NR_CPUS + 1,
 	.nr		= {-1, -1, -1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_SOFTNET_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_SOFTNET_SIZE,
 	.msize		= STATS_SOFTNET_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= &cpu_bitmap
 };
 
@@ -1895,10 +2090,10 @@ struct activity psi_cpu_act = {
 	.f_raw_print	= raw_print_psicpu_stats,
 	.f_pcp_print	= pcp_print_psicpu_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "Pressure-stall CPU statistics",
 #endif
 	.name		= "A_PSI_CPU",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 2,
 	.nr_ini		= 1,
@@ -1906,10 +2101,15 @@ struct activity psi_cpu_act = {
 	.nr_max		= 1,
 	.nr		= {1, 1, 1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_PSI_CPU_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_PSI_CPU_SIZE,
 	.msize		= STATS_PSI_CPU_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -1941,10 +2141,10 @@ struct activity psi_io_act = {
 	.f_raw_print	= raw_print_psiio_stats,
 	.f_pcp_print	= pcp_print_psiio_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "Pressure-stall I/O statistics",
 #endif
 	.name		= "A_PSI_IO",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 4,
 	.nr_ini		= 1,
@@ -1952,10 +2152,15 @@ struct activity psi_io_act = {
 	.nr_max		= 1,
 	.nr		= {1, 1, 1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_PSI_IO_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_PSI_IO_SIZE,
 	.msize		= STATS_PSI_IO_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -1987,10 +2192,10 @@ struct activity psi_mem_act = {
 	.f_raw_print	= raw_print_psimem_stats,
 	.f_pcp_print	= pcp_print_psimem_stats,
 	.f_count_new	= NULL,
-	.item_list	= NULL,
 	.desc		= "Pressure-stall memory statistics",
 #endif
 	.name		= "A_PSI_MEM",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 4,
 	.nr_ini		= 1,
@@ -1998,10 +2203,15 @@ struct activity psi_mem_act = {
 	.nr_max		= 1,
 	.nr		= {1, 1, 1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_PSI_MEM_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_PSI_MEM_SIZE,
 	.msize		= STATS_PSI_MEM_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
@@ -2033,10 +2243,10 @@ struct activity pwr_bat_act = {
 	.f_raw_print	= raw_print_pwr_bat_stats,
 	.f_pcp_print	= pcp_print_pwr_bat_stats,
 	.f_count_new	= count_new_bat,
-	.item_list	= NULL,
 	.desc		= "Batteries capacity",
 #endif
 	.name		= "A_PWR_BAT",
+	.item_list	= NULL,
 	.item_list_sz	= 0,
 	.g_nr		= 1,
 	.nr_ini		= -1,
@@ -2044,10 +2254,15 @@ struct activity pwr_bat_act = {
 	.nr_max		= MAX_NR_BATS,
 	.nr		= {-1, -1, -1},
 	.nr_allocated	= 0,
+	.xnr		= STATS_PWR_BAT_XNR,
+	.xdev_list	= NULL,
 	.fsize		= STATS_PWR_BAT_SIZE,
 	.msize		= STATS_PWR_BAT_SIZE,
 	.opt_flags	= 0,
 	.buf		= {NULL, NULL, NULL},
+	.spmin		= NULL,
+	.spmax		= NULL,
+	.nr_spalloc	= 0,
 	.bitmap		= NULL
 };
 
