@@ -186,75 +186,33 @@ void salloc_mp_struct(int nr_cpus, int pos)
 	int i;
 
 	for (i = 0; i < 3; i++) {
+		SREALLOC(st_cpu[i], struct stats_cpu, STATS_CPU_SIZE * nr_cpus);
+		SREALLOC(st_node[i], struct stats_cpu, STATS_CPU_SIZE * nr_cpus);
+		SREALLOC(st_irq[i], struct stats_global_irq, STATS_GLOBAL_IRQ_SIZE * nr_cpus);
+		SREALLOC(st_irqcpu[i], struct stats_irqcpu,
+			 STATS_IRQCPU_SIZE * nr_cpus * irqcpu_nr);
+		SREALLOC(st_softirqcpu[i], struct stats_irqcpu,
+			 STATS_IRQCPU_SIZE * nr_cpus * softirqcpu_nr);
+	}
 
-		if ((st_cpu[i] = (struct stats_cpu *) realloc(st_cpu[i], STATS_CPU_SIZE * nr_cpus))
-		    == NULL) {
-			perror("realloc");
-			exit(4);
-		}
+	SREALLOC(cpu_bitmap, unsigned char, (nr_cpus >> 3) + 1);
+	SREALLOC(node_bitmap, unsigned char, (nr_cpus >> 3) + 1);
 
-		if ((st_node[i] = (struct stats_cpu *) realloc(st_node[i], STATS_CPU_SIZE * nr_cpus))
-		    == NULL) {
-			perror("realloc");
-			exit(4);
-		}
+	SREALLOC(cpu_per_node, int, sizeof(int) * nr_cpus);
+	SREALLOC(cpu2node, int, sizeof(int) * nr_cpus);
+	SREALLOC(st_cpu_topology, struct cpu_topology, sizeof(struct cpu_topology) * nr_cpus);
 
-		if ((st_irq[i] = (struct stats_global_irq *) realloc(st_irq[i],
-								     STATS_GLOBAL_IRQ_SIZE * nr_cpus))
-		    == NULL) {
-			perror("realloc");
-			exit(4);
-		}
-
-		if ((st_irqcpu[i] = (struct stats_irqcpu *) realloc(st_irqcpu[i],
-								    STATS_IRQCPU_SIZE * nr_cpus * irqcpu_nr))
-		    == NULL) {
-			perror("realloc");
-			exit(4);
-		}
-
-		if ((st_softirqcpu[i] = (struct stats_irqcpu *) realloc(st_softirqcpu[i],
-									STATS_IRQCPU_SIZE * nr_cpus * softirqcpu_nr))
-		     == NULL) {
-			perror("realloc");
-			exit(4);
+	if (pos) {
+		/* Init already done in SREALLOC macro if @pos == 0 */
+		for (i = 0; i < 3; i++) {
+			memset(st_cpu[i] + pos, 0, STATS_CPU_SIZE * (nr_cpus - pos));
+			memset(st_node[i] + pos, 0, STATS_CPU_SIZE * (nr_cpus - pos));
+			memset(st_irq[i] + pos, 0, STATS_GLOBAL_IRQ_SIZE * (nr_cpus - pos));
+			memset(st_irqcpu[i] + pos, 0, STATS_IRQCPU_SIZE * (nr_cpus - pos) * irqcpu_nr);
+			memset(st_softirqcpu[i] + pos, 0, STATS_IRQCPU_SIZE * (nr_cpus - pos) * softirqcpu_nr);
 		}
 	}
-
-	if ((cpu_bitmap = (unsigned char *) realloc(cpu_bitmap, (nr_cpus >> 3) + 1)) == NULL) {
-		perror("realloc");
-		exit(4);
-	}
-
-	if ((node_bitmap = (unsigned char *) realloc(node_bitmap, (nr_cpus >> 3) + 1)) == NULL) {
-		perror("realloc");
-		exit(4);
-	}
-
-	if ((cpu_per_node = (int *) realloc(cpu_per_node, sizeof(int) * nr_cpus)) == NULL) {
-		perror("realloc");
-		exit(4);
-	}
-
-	if ((cpu2node = (int *) realloc(cpu2node, sizeof(int) * nr_cpus)) == NULL) {
-		perror("realloc");
-		exit(4);
-	}
-
-	if ((st_cpu_topology = (struct cpu_topology *) realloc(st_cpu_topology,
-							       sizeof(struct cpu_topology) * nr_cpus)) == NULL) {
-		perror("realloc");
-		exit(4);
-	}
-
-	for (i = 0; i < 3; i++) {
-		memset(st_cpu[i] + pos, 0, STATS_CPU_SIZE * (nr_cpus - pos));
-		memset(st_node[i] + pos, 0, STATS_CPU_SIZE * (nr_cpus - pos));
-		memset(st_irq[i] + pos, 0, STATS_GLOBAL_IRQ_SIZE * (nr_cpus - pos));
-		memset(st_irqcpu[i] + pos, 0, STATS_IRQCPU_SIZE * (nr_cpus - pos) * irqcpu_nr);
-		memset(st_softirqcpu[i] + pos, 0, STATS_IRQCPU_SIZE * (nr_cpus - pos) * softirqcpu_nr);
-	}
-	if (!pos) {
+	else {
 		memset(cpu_bitmap, 0, (nr_cpus >> 3) + 1);
 		memset(node_bitmap, 0, (nr_cpus >> 3) + 1);
 	}
@@ -663,7 +621,8 @@ unsigned long long get_global_cpu_mpstats(int prev, int curr,
  ***************************************************************************
  */
 void write_plain_cpu_stats(int dis, unsigned long long deltot_jiffies, int prev, int curr,
-			   char *prev_string, char *curr_string, unsigned char offline_cpu_bitmap[])
+			   char *prev_string, char *curr_string,
+			   const unsigned char offline_cpu_bitmap[])
 {
 	int i;
 	struct stats_cpu *scc, *scp;
@@ -777,7 +736,7 @@ void write_plain_cpu_stats(int dis, unsigned long long deltot_jiffies, int prev,
  ***************************************************************************
  */
 void write_json_cpu_stats(int tab, unsigned long long deltot_jiffies, int prev, int curr,
-			  unsigned char offline_cpu_bitmap[])
+			  const unsigned char offline_cpu_bitmap[])
 {
 	int i, next = FALSE;
 	char cpu_name[16], topology[1024] = "";
@@ -1214,7 +1173,8 @@ void write_node_stats(int dis, unsigned long long deltot_jiffies, int prev, int
  ***************************************************************************
  */
 void write_plain_isumcpu_stats(int dis, unsigned long long itv, int prev, int curr,
-			       char *prev_string, char *curr_string, unsigned char offline_cpu_bitmap[])
+			       char *prev_string, char *curr_string,
+			       const unsigned char offline_cpu_bitmap[])
 {
 	struct stats_cpu *scc, *scp;
 	struct stats_global_irq *sic, *sip;
@@ -1283,7 +1243,7 @@ void write_plain_isumcpu_stats(int dis, unsigned long long itv, int prev, int cu
  ***************************************************************************
  */
 void write_json_isumcpu_stats(int tab, unsigned long long itv, int prev, int curr,
-			      unsigned char offline_cpu_bitmap[])
+			      const unsigned char offline_cpu_bitmap[])
 {
 	struct stats_cpu *scc, *scp;
 	struct stats_global_irq *sic, *sip;
@@ -1403,7 +1363,8 @@ void write_isumcpu_stats(int dis, unsigned long long itv, int prev, int curr,
  */
 void write_plain_irqcpu_stats(struct stats_irqcpu *st_ic[], int ic_nr, int dis,
 			      unsigned long long itv, int prev, int curr,
-			      char *prev_string, char *curr_string, unsigned char offline_cpu_bitmap[])
+			      char *prev_string, char *curr_string,
+			      const unsigned char offline_cpu_bitmap[])
 {
 	int j = ic_nr, offset, cpu, colwidth[NR_IRQS];
 	struct stats_irqcpu *p, *q, *p0, *q0;
@@ -1542,7 +1503,7 @@ void write_plain_irqcpu_stats(struct stats_irqcpu *st_ic[], int ic_nr, int dis,
  */
 void write_json_irqcpu_stats(int tab, struct stats_irqcpu *st_ic[], int ic_nr,
 			     unsigned long long itv, int prev, int curr, int type,
-			     unsigned char offline_cpu_bitmap[])
+			     const unsigned char offline_cpu_bitmap[])
 {
 	int j = ic_nr, offset, cpu;
 	struct stats_irqcpu *p, *q, *p0, *q0;
@@ -1971,7 +1932,7 @@ void read_interrupts_stat(char *file, struct stats_irqcpu *st_ic[], int ic_nr, i
 void rw_mpstat_loop(int dis_hdr, int rows)
 {
 	struct stats_cpu *scc;
-	int i, new_cpu_nr;
+	int new_cpu_nr;
 	int curr = 1, dis = 1;
 	unsigned long lines = rows;
 
@@ -1985,6 +1946,8 @@ void rw_mpstat_loop(int dis_hdr, int rows)
 	 * read from /proc/stat for global CPU stats.
 	 */
 	if (cpu_nr > 1) {
+		int i;
+
 		memset(st_cpu[0], 0, STATS_CPU_SIZE);
 
 		for (i = 1; i <= cpu_nr; i++) {
@@ -2221,6 +2184,11 @@ int main(int argc, char **argv)
 	while (++opt < argc) {
 
 		if (!strncmp(argv[opt], "--dec=", 6) && (strlen(argv[opt]) == 7)) {
+			/* Check that the argument is a digit */
+			if (!isdigit(argv[opt][6])) {
+				usage(argv[0]);
+			}
+
 			/* Get number of decimal places */
 			dplaces_nr = atoi(argv[opt] + 6);
 			if ((dplaces_nr < 0) || (dplaces_nr > 2)) {
