@@ -26,7 +26,6 @@
 
 #include "sa.h"
 #include "ioconf.h"
-#include "raw_stats.h"
 
 extern uint64_t flags;
 extern char bat_status[][16];
@@ -49,14 +48,15 @@ extern char bat_status[][16];
  */
 char *pfield(char *hdr_line, int pos)
 {
-	char hline[HEADER_LINE_LEN] = "";
 	static char field[HEADER_LINE_LEN] = "";
 	static char gen_name[HEADER_LINE_LEN] = "";
 	static int idx = 0;
-	char *hl;
 	int i, j = 0;
 
 	if (hdr_line) {
+		char hline[HEADER_LINE_LEN] = "";
+		char *hl;
+
 		strncpy(hline, hdr_line, sizeof(hline) - 1);
 		hline[sizeof(hline) - 1] = '\0';
 		idx = 0;
@@ -390,6 +390,56 @@ __print_funct_t raw_print_io_stats(struct activity *a, char *timestr, int curr)
 	printf("\n");
 }
 
+/*
+ * **************************************************************************
+ * Display RAM memory utilization in raw format.
+ *
+ * IN:
+ * @smc		Structure with statistics.
+ * @dispall	TRUE if all memory fields should be displayed.
+ ***************************************************************************
+ */
+void raw_print_ram_memory_stats(struct stats_memory *smc, int dispall)
+{
+	printf(" %s; %llu;", pfield(NULL, 0), smc->availablekb);
+	printf(" kbttlmem; %llu;", smc->tlmkb);
+	pfield(NULL, 0); /* Skip kbmemused */
+	pfield(NULL, 0); /* Skip %memused */
+	printf(" %s; %llu;", pfield(NULL, 0), smc->bufkb);
+	printf(" %s; %llu;", pfield(NULL, 0), smc->camkb);
+	printf(" %s; %llu;", pfield(NULL, 0), smc->comkb);
+	pfield(NULL, 0); /* Skip %commit */
+	printf(" %s; %llu;", pfield(NULL, 0), smc->activekb);
+	printf(" %s; %llu;", pfield(NULL, 0), smc->inactkb);
+	printf(" %s; %llu;", pfield(NULL, 0), smc->dirtykb);
+
+	if (dispall) {
+		printf(" %s; %llu;", pfield(NULL, 0), smc->anonpgkb);
+		printf(" %s; %llu;", pfield(NULL, 0), smc->slabkb);
+		printf(" %s; %llu;", pfield(NULL, 0), smc->kstackkb);
+		printf(" %s; %llu;", pfield(NULL, 0), smc->pgtblkb);
+		printf(" %s; %llu;", pfield(NULL, 0), smc->vmusedkb);
+	}
+	printf("\n");
+}
+
+/*
+ * **************************************************************************
+ * Display swap memory utilization in raw format.
+ *
+ * IN:
+ * @smc		Structure with statistics.
+ ***************************************************************************
+ */
+void raw_print_swap_memory_stats(struct stats_memory *smc)
+{
+	printf(" kbttlswp; %llu;", smc->tlskb);
+	pfield(NULL, 0); /* Skip kbswpused */
+	pfield(NULL, 0); /* Skip %swpused */
+	printf(" %s; %llu;", pfield(NULL, 0), smc->caskb);
+	printf("\n");
+}
+
 /*
  ***************************************************************************
  * Display memory statistics in raw format.
@@ -407,35 +457,12 @@ __print_funct_t raw_print_memory_stats(struct activity *a, char *timestr, int cu
 
 	if (DISPLAY_MEMORY(a->opt_flags)) {
 		printf("%s; %s; %llu;", timestr, pfield(a->hdr_line, FIRST), smc->frmkb);
-		printf(" %s; %llu;", pfield(NULL, 0), smc->availablekb);
-		printf(" kbttlmem; %llu;", smc->tlmkb);
-		pfield(NULL, 0); /* Skip kbmemused */
-		pfield(NULL, 0); /* Skip %memused */
-		printf(" %s; %llu;", pfield(NULL, 0), smc->bufkb);
-		printf(" %s; %llu;", pfield(NULL, 0), smc->camkb);
-		printf(" %s; %llu;", pfield(NULL, 0), smc->comkb);
-		pfield(NULL, 0); /* Skip %commit */
-		printf(" %s; %llu;", pfield(NULL, 0), smc->activekb);
-		printf(" %s; %llu;", pfield(NULL, 0), smc->inactkb);
-		printf(" %s; %llu;", pfield(NULL, 0), smc->dirtykb);
-
-		if (DISPLAY_MEM_ALL(a->opt_flags)) {
-			printf(" %s; %llu;", pfield(NULL, 0), smc->anonpgkb);
-			printf(" %s; %llu;", pfield(NULL, 0), smc->slabkb);
-			printf(" %s; %llu;", pfield(NULL, 0), smc->kstackkb);
-			printf(" %s; %llu;", pfield(NULL, 0), smc->pgtblkb);
-			printf(" %s; %llu;", pfield(NULL, 0), smc->vmusedkb);
-		}
-		printf("\n");
+		raw_print_ram_memory_stats(smc, DISPLAY_MEM_ALL(a->opt_flags));
 	}
 
 	if (DISPLAY_SWAP(a->opt_flags)) {
 		printf("%s; %s; %llu;", timestr, pfield(a->hdr_line, SECOND), smc->frskb);
-		printf(" kbttlswp; %llu;", smc->tlskb);
-		pfield(NULL, 0); /* Skip kbswpused */
-		pfield(NULL, 0); /* Skip %swpused */
-		printf(" %s; %llu;", pfield(NULL, 0), smc->caskb);
-		printf("\n");
+		raw_print_swap_memory_stats(smc);
 	}
 }
 
@@ -684,7 +711,7 @@ __print_funct_t raw_print_net_dev_stats(struct activity *a, char *timestr, int c
 		pval(sndp->tx_compressed, sndc->tx_compressed);
 		printf(" %s", pfield(NULL, 0));
 		pval(sndp->multicast, sndc->multicast);
-		printf(" speed; %u; duplex; %u;\n", sndc->speed, sndc->duplex);
+		printf(" speed; %u; duplex; %u;\n", sndc->speed, (unsigned int) sndc->duplex);
 	}
 }
 
@@ -1521,7 +1548,7 @@ __print_funct_t raw_print_pwr_usb_stats(struct activity *a, char *timestr, int c
 
 		printf("%s; %s; \"%s\";", timestr, pfield(a->hdr_line, FIRST), suc->manufacturer);
 		printf(" %s; \"%s\";", pfield(NULL, 0), suc->product);
-		printf(" %s; %d;", pfield(NULL, 0), suc->bus_nr);
+		printf(" %s; %u;", pfield(NULL, 0), suc->bus_nr);
 		printf(" %s; %x;", pfield(NULL, 0), suc->vendor_id);
 		printf(" %s; %x;", pfield(NULL, 0), suc->product_id);
 		printf(" %s; %u;\n", pfield(NULL, 0), suc->bmaxpower);
