@@ -448,16 +448,18 @@ void read_uptime(unsigned long long *uptime)
 void compute_ext_disk_stats(struct stats_disk *sdc, struct stats_disk *sdp,
 			    unsigned long long itv, struct ext_disk_stats *xds)
 {
-	xds->util  = S_VALUE(sdp->tot_ticks, sdc->tot_ticks, itv);
+	xds->util  = sdc->tot_ticks < sdp->tot_ticks ?
+		     0.0 :
+		     S_VALUE(sdp->tot_ticks, sdc->tot_ticks, itv);
 	/*
 	 * Kernel gives ticks already in milliseconds for all platforms
 	 * => no need for further scaling.
 	 * Origin (unmerged) flush operations are counted as writes.
 	 */
-	xds->await = (sdc->nr_ios - sdp->nr_ios) ?
+	xds->await = (sdc->nr_ios > sdp->nr_ios) ?
 		((sdc->rd_ticks - sdp->rd_ticks) + (sdc->wr_ticks - sdp->wr_ticks) + (sdc->dc_ticks - sdp->dc_ticks)) /
 		((double) (sdc->nr_ios - sdp->nr_ios)) : 0.0;
-	xds->arqsz = (sdc->nr_ios - sdp->nr_ios) ?
+	xds->arqsz = (sdc->nr_ios > sdp->nr_ios) ?
 		((sdc->rd_sect - sdp->rd_sect) + (sdc->wr_sect - sdp->wr_sect) + (sdc->dc_sect - sdp->dc_sect)) /
 		((double) (sdc->nr_ios - sdp->nr_ios)) : 0.0;
 }
@@ -832,7 +834,7 @@ __nr_t read_diskstats_io(struct stats_io *st_io)
 		dc_ios = dc_sec = 0;
 
 		if (sscanf(line,
-			   "%u %u %s "
+			   "%u %u %127s "
 			   "%lu %*u %lu %*u "
 			   "%lu %*u %lu %*u "
 			   "%*u %*u %*u "
@@ -903,7 +905,7 @@ __nr_t read_diskstats_disk(struct stats_disk *st_disk, __nr_t nr_alloc,
 		dc_ios = dc_sec = dc_ticks = 0;
 
 		if (sscanf(line,
-			   "%u %u %s "
+			   "%u %u %127s "
 			   "%lu %*u %lu %u "
 			   "%lu %*u %lu %u "
 			   "%*u %u %u "
@@ -1039,7 +1041,7 @@ __nr_t read_kernel_tables(struct stats_ktables *st_ktables)
 {
 	FILE *fp;
 	unsigned long long parm;
-	int rc = 0;
+	int rc;
 
 	/* Open /proc/sys/fs/dentry-state file */
 	if ((fp = fopen(FDENTRY_STATE, "r")) != NULL) {
@@ -1139,7 +1141,7 @@ __nr_t read_net_dev(struct stats_net_dev *st_net_dev, __nr_t nr_alloc)
 			st_net_dev_i = st_net_dev + dev_read++;
 			strncpy(iface, line, MINIMUM(pos, sizeof(iface) - 1));
 			iface[MINIMUM(pos, sizeof(iface) - 1)] = '\0';
-			sscanf(iface, "%s", st_net_dev_i->interface); /* Skip heading spaces */
+			sscanf(iface, "%15s", st_net_dev_i->interface); /* Skip heading spaces */
 			sscanf(line + pos + 1, "%llu %llu %*u %*u %*u %*u %llu %llu %llu %llu "
 			       "%*u %*u %*u %*u %*u %llu",
 			       &st_net_dev_i->rx_bytes,
@@ -1262,7 +1264,7 @@ __nr_t read_net_edev(struct stats_net_edev *st_net_edev, __nr_t nr_alloc)
 			st_net_edev_i = st_net_edev + dev_read++;
 			strncpy(iface, line, MINIMUM(pos, sizeof(iface) - 1));
 			iface[MINIMUM(pos, sizeof(iface) - 1)] = '\0';
-			sscanf(iface, "%s", st_net_edev_i->interface); /* Skip heading spaces */
+			sscanf(iface, "%15s", st_net_edev_i->interface); /* Skip heading spaces */
 			sscanf(line + pos + 1, "%*u %*u %llu %llu %llu %llu %*u %*u %*u %*u "
 			       "%llu %llu %llu %llu %llu",
 			       &st_net_edev_i->rx_errors,
@@ -2592,7 +2594,7 @@ __nr_t read_filesystem(struct stats_filesystem *st_filesystem, __nr_t nr_alloc)
 {
 	FILE *fp;
 	char line[512], fs_name[MAX_FS_LEN], mountp[256], type[128];
-	int skip = 0, skip_next = 0, fs;
+	int skip, skip_next = 0, fs;
 	char *pos = 0, *pos2 = 0;
 	__nr_t fs_read = 0;
 	struct stats_filesystem *st_filesystem_i;
@@ -2803,12 +2805,13 @@ __nr_t read_fchost(struct stats_fchost *st_fc, __nr_t nr_alloc)
  ***************************************************************************
  */
 int read_softnet(struct stats_softnet *st_softnet, __nr_t nr_alloc,
-		 unsigned char online_cpu_bitmap[])
+		 const unsigned char online_cpu_bitmap[])
 {
 	FILE *fp;
 	struct stats_softnet *st_softnet_i, st_softnet_read;
 	char line[1024];
-	int cpu = 1, rc = 1, i, cpu_id;
+	int rc = 1, i;
+	unsigned int cpu = 1, cpu_id;
 
 	/* Open /proc/net/softnet_stat file */
 	if ((fp = fopen(NET_SOFTNET, "r")) == NULL)
