@@ -128,6 +128,7 @@ struct stats_cpu {
 #define STATS_CPU_ULL	10
 #define STATS_CPU_UL	0
 #define STATS_CPU_U	0
+#define STATS_CPU_XNR	10
 
 /*
  * Structure for task creation and context switch statistics.
@@ -143,6 +144,7 @@ struct stats_pcsw {
 #define STATS_PCSW_ULL	1
 #define STATS_PCSW_UL	1
 #define STATS_PCSW_U	0
+#define STATS_PCSW_XNR	2
 
 /*
  * Structure for interrupts statistics.
@@ -161,6 +163,7 @@ struct stats_irq {
 #define STATS_IRQ_ULL	0
 #define STATS_IRQ_UL	0
 #define STATS_IRQ_U	1
+#define STATS_IRQ_XNR	1
 
 /* Structure for swapping statistics */
 struct stats_swap {
@@ -172,6 +175,7 @@ struct stats_swap {
 #define STATS_SWAP_ULL	0
 #define STATS_SWAP_UL	2
 #define STATS_SWAP_U	0
+#define STATS_SWAP_XNR	2
 
 /* Structure for paging statistics */
 struct stats_paging {
@@ -189,6 +193,7 @@ struct stats_paging {
 #define STATS_PAGING_ULL	0
 #define STATS_PAGING_UL		8
 #define STATS_PAGING_U		0
+#define STATS_PAGING_XNR	9
 
 /* Structure for I/O and transfer rate statistics */
 struct stats_io {
@@ -205,6 +210,7 @@ struct stats_io {
 #define STATS_IO_ULL	7
 #define STATS_IO_UL	0
 #define STATS_IO_U	0
+#define STATS_IO_XNR	7
 
 /*
  * Structure for memory and swap space utilization statistics.
@@ -235,6 +241,7 @@ struct stats_memory {
 #define STATS_MEMORY_ULL	17
 #define STATS_MEMORY_UL		0
 #define STATS_MEMORY_U		0
+#define STATS_MEMORY_XNR	21
 
 /* Structure for kernel tables statistics */
 struct stats_ktables {
@@ -248,6 +255,7 @@ struct stats_ktables {
 #define STATS_KTABLES_ULL	4
 #define STATS_KTABLES_UL	0
 #define STATS_KTABLES_U		0
+#define STATS_KTABLES_XNR	4
 
 /* Structure for queue and load statistics */
 struct stats_queue {
@@ -263,6 +271,7 @@ struct stats_queue {
 #define STATS_QUEUE_ULL		3
 #define STATS_QUEUE_UL		0
 #define STATS_QUEUE_U		3
+#define STATS_QUEUE_XNR		6
 
 /* Structure for serial statistics */
 struct stats_serial {
@@ -279,6 +288,7 @@ struct stats_serial {
 #define STATS_SERIAL_ULL	0
 #define STATS_SERIAL_UL		0
 #define STATS_SERIAL_U		7
+#define STATS_SERIAL_XNR	6
 
 /*
  * Structure for block devices statistics.
@@ -305,6 +315,7 @@ struct stats_disk {
 #define STATS_DISK_ULL	3
 #define STATS_DISK_UL	3
 #define STATS_DISK_U	8
+#define STATS_DISK_XNR	8
 
 /* Structure for network interfaces statistics */
 struct stats_net_dev {
@@ -325,6 +336,7 @@ struct stats_net_dev {
 #define STATS_NET_DEV_ULL	7
 #define STATS_NET_DEV_UL	0
 #define STATS_NET_DEV_U		1
+#define STATS_NET_DEV_XNR	8
 
 /* Structure for network interface errors statistics */
 struct stats_net_edev {
@@ -345,6 +357,7 @@ struct stats_net_edev {
 #define STATS_NET_EDEV_ULL	9
 #define STATS_NET_EDEV_UL	0
 #define STATS_NET_EDEV_U	0
+#define STATS_NET_EDEV_XNR	9
 
 /* Structure for NFS client statistics */
 struct stats_net_nfs {
@@ -360,6 +373,7 @@ struct stats_net_nfs {
 #define STATS_NET_NFS_ULL	0
 #define STATS_NET_NFS_UL	0
 #define STATS_NET_NFS_U		6
+#define STATS_NET_NFS_XNR	6
 
 /* Structure for NFS server statistics */
 struct stats_net_nfsd {
@@ -380,6 +394,7 @@ struct stats_net_nfsd {
 #define STATS_NET_NFSD_ULL	0
 #define STATS_NET_NFSD_UL	0
 #define STATS_NET_NFSD_U	11
+#define STATS_NET_NFSD_XNR	11
 
 /* Structure for IPv4 sockets statistics */
 struct stats_net_sock {
@@ -395,6 +410,7 @@ struct stats_net_sock {
 #define STATS_NET_SOCK_ULL	0
 #define STATS_NET_SOCK_UL	0
 #define STATS_NET_SOCK_U	6
+#define STATS_NET_SOCK_XNR	6
 
 /* Structure for IP statistics */
 struct stats_net_ip {
@@ -412,6 +428,7 @@ struct stats_net_ip {
 #define STATS_NET_IP_ULL	8
 #define STATS_NET_IP_UL		0
 #define STATS_NET_IP_U		0
+#define STATS_NET_IP_XNR	8
 
 /* Structure for IP errors statistics */
 struct stats_net_eip {
@@ -429,6 +446,7 @@ struct stats_net_eip {
 #define STATS_NET_EIP_ULL	8
 #define STATS_NET_EIP_UL	0
 #define STATS_NET_EIP_U		0
+#define STATS_NET_EIP_XNR	8
 
 /* Structure for ICMP statistics */
 struct stats_net_icmp {
@@ -452,6 +470,7 @@ struct stats_net_icmp {
 #define STATS_NET_ICMP_ULL	0
 #define STATS_NET_ICMP_UL	14
 #define STATS_NET_ICMP_U	0
+#define STATS_NET_ICMP_XNR	14
 
 /* Structure for ICMP error message statistics */
 struct stats_net_eicmp {
@@ -473,6 +492,7 @@ struct stats_net_eicmp {
 #define STATS_NET_EICMP_ULL	0
 #define STATS_NET_EICMP_UL	12
 #define STATS_NET_EICMP_U	0
+#define STATS_NET_EICMP_XNR	12
 
 /* Structure for TCP statistics */
 struct stats_net_tcp {
@@ -486,6 +506,7 @@ struct stats_net_tcp {
 #define STATS_NET_TCP_ULL	0
 #define STATS_NET_TCP_UL	4
 #define STATS_NET_TCP_U		0
+#define STATS_NET_TCP_XNR	4
 
 /* Structure for TCP errors statistics */
 struct stats_net_etcp {
@@ -500,6 +521,7 @@ struct stats_net_etcp {
 #define STATS_NET_ETCP_ULL	0
 #define STATS_NET_ETCP_UL	5
 #define STATS_NET_ETCP_U	0
+#define STATS_NET_ETCP_XNR	5
 
 /* Structure for UDP statistics */
 struct stats_net_udp {
@@ -513,6 +535,7 @@ struct stats_net_udp {
 #define STATS_NET_UDP_ULL	0
 #define STATS_NET_UDP_UL	4
 #define STATS_NET_UDP_U		0
+#define STATS_NET_UDP_XNR	4
 
 /* Structure for IPv6 sockets statistics */
 struct stats_net_sock6 {
@@ -526,6 +549,7 @@ struct stats_net_sock6 {
 #define STATS_NET_SOCK6_ULL	0
 #define STATS_NET_SOCK6_UL	0
 #define STATS_NET_SOCK6_U	4
+#define STATS_NET_SOCK6_XNR	4
 
 /* Structure for IPv6 statistics */
 struct stats_net_ip6 {
@@ -545,6 +569,7 @@ struct stats_net_ip6 {
 #define STATS_NET_IP6_ULL	10
 #define STATS_NET_IP6_UL	0
 #define STATS_NET_IP6_U		0
+#define STATS_NET_IP6_XNR	10
 
 /* Structure for IPv6 errors statistics */
 struct stats_net_eip6 {
@@ -565,6 +590,7 @@ struct stats_net_eip6 {
 #define STATS_NET_EIP6_ULL	11
 #define STATS_NET_EIP6_UL	0
 #define STATS_NET_EIP6_U	0
+#define STATS_NET_EIP6_XNR	11
 
 /* Structure for ICMPv6 statistics */
 struct stats_net_icmp6 {
@@ -591,6 +617,7 @@ struct stats_net_icmp6 {
 #define STATS_NET_ICMP6_ULL	0
 #define STATS_NET_ICMP6_UL	17
 #define STATS_NET_ICMP6_U	0
+#define STATS_NET_ICMP6_XNR	17
 
 /* Structure for ICMPv6 error message statistics */
 struct stats_net_eicmp6 {
@@ -611,6 +638,7 @@ struct stats_net_eicmp6 {
 #define STATS_NET_EICMP6_ULL	0
 #define STATS_NET_EICMP6_UL	11
 #define STATS_NET_EICMP6_U	0
+#define STATS_NET_EICMP6_XNR	11
 
 /* Structure for UDPv6 statistics */
 struct stats_net_udp6 {
@@ -624,6 +652,7 @@ struct stats_net_udp6 {
 #define STATS_NET_UDP6_ULL	0
 #define STATS_NET_UDP6_UL	4
 #define STATS_NET_UDP6_U	0
+#define STATS_NET_UDP6_XNR	4
 
 /*
  * Structure for CPU frequency statistics.
@@ -638,6 +667,7 @@ struct stats_pwr_cpufreq {
 #define STATS_PWR_CPUFREQ_ULL	0
 #define STATS_PWR_CPUFREQ_UL	1
 #define STATS_PWR_CPUFREQ_U	0
+#define STATS_PWR_CPUFREQ_XNR	1
 
 /* Structure for hugepages statistics */
 struct stats_huge {
@@ -651,6 +681,7 @@ struct stats_huge {
 #define STATS_HUGE_ULL	4
 #define STATS_HUGE_UL	0
 #define STATS_HUGE_U	0
+#define STATS_HUGE_XNR	5
 
 /*
  * Structure for weighted CPU frequency statistics.
@@ -666,6 +697,7 @@ struct stats_pwr_wghfreq {
 #define STATS_PWR_WGHFREQ_ULL	1
 #define STATS_PWR_WGHFREQ_UL	1
 #define STATS_PWR_WGHFREQ_U	0
+#define STATS_PWR_WGHFREQ_XNR	1
 
 /*
  * Structure for USB devices plugged into the system.
@@ -683,6 +715,7 @@ struct stats_pwr_usb {
 #define STATS_PWR_USB_ULL	0
 #define STATS_PWR_USB_UL	0
 #define STATS_PWR_USB_U		4
+#define STATS_PWR_USB_XNR	0
 
 /* Structure for filesystems statistics */
 struct stats_filesystem {
@@ -700,6 +733,7 @@ struct stats_filesystem {
 #define STATS_FILESYSTEM_ULL		5
 #define STATS_FILESYSTEM_UL		0
 #define STATS_FILESYSTEM_U		0
+#define STATS_FILESYSTEM_XNR		7
 
 /* Structure for Fibre Channel HBA statistics */
 struct stats_fchost {
@@ -714,6 +748,7 @@ struct stats_fchost {
 #define STATS_FCHOST_ULL	0
 #define STATS_FCHOST_UL		4
 #define STATS_FCHOST_U		0
+#define STATS_FCHOST_XNR	4
 
 /* Structure for softnet statistics */
 struct stats_softnet {
@@ -729,6 +764,7 @@ struct stats_softnet {
 #define STATS_SOFTNET_ULL	0
 #define STATS_SOFTNET_UL	0
 #define STATS_SOFTNET_U		6
+#define STATS_SOFTNET_XNR	6
 
 /* Structure for pressure-stall CPU statistics */
 struct stats_psi_cpu {
@@ -742,6 +778,7 @@ struct stats_psi_cpu {
 #define STATS_PSI_CPU_ULL	1
 #define STATS_PSI_CPU_UL	3
 #define STATS_PSI_CPU_U		0
+#define STATS_PSI_CPU_XNR	4
 
 /* Structure for pressure-stall I/O statistics */
 struct stats_psi_io {
@@ -759,6 +796,7 @@ struct stats_psi_io {
 #define STATS_PSI_IO_ULL	2
 #define STATS_PSI_IO_UL		6
 #define STATS_PSI_IO_U		0
+#define STATS_PSI_IO_XNR	8
 
 /* Structure for pressure-stall memory statistics */
 struct stats_psi_mem {
@@ -776,6 +814,7 @@ struct stats_psi_mem {
 #define STATS_PSI_MEM_ULL	2
 #define STATS_PSI_MEM_UL	6
 #define STATS_PSI_MEM_U		0
+#define STATS_PSI_MEM_XNR	8
 
 /* Structure for batteries statistics */
 struct stats_pwr_bat {
@@ -788,6 +827,7 @@ struct stats_pwr_bat {
 #define STATS_PWR_BAT_ULL	0
 #define STATS_PWR_BAT_UL	0
 #define STATS_PWR_BAT_U		0
+#define STATS_PWR_BAT_XNR	2
 
 /*
  ***************************************************************************
@@ -878,7 +918,7 @@ __nr_t read_filesystem
 __nr_t read_fchost
 	(struct stats_fchost *, __nr_t);
 int read_softnet
-	(struct stats_softnet *, __nr_t, unsigned char []);
+	(struct stats_softnet *, __nr_t, const unsigned char []);
 __nr_t read_psicpu
 	(struct stats_psi_cpu *);
 __nr_t read_psiio
