@@ -301,7 +301,8 @@ int read_next_sample(int ifd, int action, int curr, char *file, int *rtype, int
 			 */
 			if (!(action & DONT_READ_CPU_NR)) {
 				file_hdr.sa_cpu_nr = read_nr_value(ifd, file, file_magic,
-								   endian_mismatch, arch_64, TRUE);
+								   endian_mismatch, arch_64, TRUE,
+								   NR_CPUS + 1);
 
 				/* Ignore unknown extra structures if present */
 				if (record_hdr[curr].extra_next && (skip_extra_struct(ifd, endian_mismatch, arch_64) < 0))
@@ -326,7 +327,8 @@ int read_next_sample(int ifd, int action, int curr, char *file, int *rtype, int
 		 * So read now the extra fields.
 		 */
 		if (read_file_stat_bunch(act, curr, ifd, file_hdr.sa_act_nr, file_actlst,
-					 endian_mismatch, arch_64, file, file_magic, oneof) > 0)
+					 endian_mismatch, arch_64, file, file_magic, oneof,
+					 flags) > 0)
 			return 2;
 		if (sa_get_record_timestamp_struct(flags, &record_hdr[curr], rectime))
 			return 2;
@@ -1240,7 +1242,7 @@ void logic2_display_loop(int ifd, char *file, struct file_activity *file_actlst,
 {
 	int i, p;
 	int curr = 1, rtype;
-	int eosaf = TRUE, reset = FALSE;
+	int eosaf = TRUE, reset;
 	long cnt = 1;
 
 	/* Read system statistics from file */
@@ -1500,7 +1502,7 @@ void read_stats_from_file(char dfile[], char pcparchive[])
 	}
 
 	/* Perform required allocations */
-	allocate_structures(act);
+	allocate_structures(act, flags);
 
 	if (SET_LC_NUMERIC_C(fmt[f_position]->options)) {
 		/* Use a decimal point */
@@ -1759,6 +1761,7 @@ int main(int argc, char **argv)
 							usage(argv[0]);
 						}
 						format = F_SVG_OUTPUT;
+						flags |= S_F_MINMAX;
 						break;
 
 					case 'h':
