@@ -28,6 +28,7 @@
 #include <errno.h>
 #include <signal.h>
 #include <sys/stat.h>
+#include <ctype.h>
 
 #include "version.h"
 #include "sa.h"
@@ -55,6 +56,11 @@ long interval = -1, count = 0;
 
 /* TRUE if a header line must be printed */
 int dish = TRUE;
+/*
+ * TRUE if min/max values should be initialized.
+ * Note: Never set to TRUE if option -x has not been used with sar.
+ */
+int xinit = FALSE;
 /* TRUE if data read from file don't match current machine's endianness */
 int endian_mismatch = FALSE;
 /* TRUE if file's data come from a 64 bit machine */
@@ -123,7 +129,7 @@ void usage(char *progname)
 	fprintf(stderr, _("Options are:\n"
 			  "[ -A ] [ -B ] [ -b ] [ -C ] [ -D ] [ -d ] [ -F [ MOUNT ] ] [ -H ] [ -h ]\n"
 			  "[ -p ] [ -r [ ALL ] ] [ -S ] [ -t ] [ -u [ ALL ] ] [ -V ]\n"
-			  "[ -v ] [ -W ] [ -w ] [ -y ] [ -z ]\n"
+			  "[ -v ] [ -W ] [ -w ] [ -x ] [ -y ] [ -z ]\n"
 			  "[ -I [ SUM | ALL ] ] [ -P { <cpu_list> | ALL } ]\n"
 			  "[ -m { <keyword> [,...] | ALL } ] [ -n { <keyword> [,...] | ALL } ]\n"
 			  "[ -q [ <keyword> [,...] | ALL ] ]\n"
@@ -384,7 +390,13 @@ void write_stats_avg(int curr, int read_from_file, unsigned int act_id)
 
 	strncpy(timestamp[curr], _("Average:"), sizeof(timestamp[curr]));
 	timestamp[curr][sizeof(timestamp[curr]) - 1] = '\0';
-	memcpy(timestamp[!curr], timestamp[curr], sizeof(timestamp[!curr]));
+	if (DISPLAY_MINMAX(flags)) {
+		strncpy(timestamp[!curr], _("Summary:"), sizeof(timestamp[!curr]));
+		timestamp[!curr][sizeof(timestamp[!curr]) - 1] = '\0';
+	}
+	else {
+		memcpy(timestamp[!curr], timestamp[curr], sizeof(timestamp[!curr]));
+	}
 
 	/* Test stdout */
 	TEST_STDOUT(STDOUT_FILENO);
@@ -617,7 +629,7 @@ __printf_funct_t print_sar_restart(int *tab, int action, char *cur_date, char *c
 	char restart[64];
 
 	printf("\n%-11s", cur_time);
-	sprintf(restart, "  LINUX RESTART\t(%d CPU)\n",
+	sprintf(restart, "  LINUX RESTART\t(%u CPU)\n",
 		file_hdr->sa_cpu_nr > 1 ? file_hdr->sa_cpu_nr - 1 : 1);
 	cprintf_s(IS_RESTART, "%s", restart);
 
@@ -695,7 +707,7 @@ void read_sadc_stat_bunch(int curr)
 				print_read_error(INCONSISTENT_INPUT_DATA);
 			}
 			if (act[p]->nr[curr] > act[p]->nr_allocated) {
-				reallocate_all_buffers(act[p], act[p]->nr[curr]);
+				reallocate_buffers(act[p], act[p]->nr[curr], flags);
 			}
 
 			/*
@@ -778,6 +790,11 @@ void handle_curr_act_stats(int ifd, off_t fpos, int *curr, long *cnt, int *eosaf
 	}
 	reset_cd = 1;
 
+	/* Min/max values should be initialized the first time */
+	if (DISPLAY_MINMAX(flags)) {
+		xinit = TRUE;
+	}
+
 	do {
 		/*
 		 * Display <count> lines of stats.
@@ -802,7 +819,7 @@ void handle_curr_act_stats(int ifd, off_t fpos, int *curr, long *cnt, int *eosaf
 		if (rtype != R_COMMENT) {
 			/* Read the extra fields since it's not a special record */
 			if (read_file_stat_bunch(act, *curr, ifd, file_hdr.sa_act_nr, file_actlst,
-						 endian_mismatch, arch_64, file, file_magic, UEOF_STOP))
+						 endian_mismatch, arch_64, file, file_magic, UEOF_STOP, flags))
 				/* Error or unexpected EOF */
 				break;
 		}
@@ -829,8 +846,11 @@ void handle_curr_act_stats(int ifd, off_t fpos, int *curr, long *cnt, int *eosaf
 		next = write_stats(*curr, USE_SA_FILE, cnt, tm_start.use, tm_end.use,
 				   *reset, act_id, reset_cd);
 		reset_cd = 0;
-		if (next && (*cnt > 0)) {
-			(*cnt)--;
+		if (next) {
+			if (*cnt > 0) {
+				(*cnt)--;
+			}
+			xinit = FALSE;
 		}
 
 		if (next) {
@@ -927,7 +947,7 @@ void read_header_data(void)
 	/* All activities are not necessarily selected, but NR_ACT is a max */
 	if (file_hdr.sa_act_nr > NR_ACT) {
 #ifdef DEBUG
-		fprintf(stderr, "%s: sa_act_nr=%d\n", __FUNCTION__, file_hdr.sa_act_nr);
+		fprintf(stderr, "%s: sa_act_nr=%u\n", __FUNCTION__, file_hdr.sa_act_nr);
 #endif
 		print_read_error(INCONSISTENT_INPUT_DATA);
 	}
@@ -965,7 +985,7 @@ void read_header_data(void)
 				fprintf(stderr, "%s: p=%d\n", __FUNCTION__, p);
 			}
 			else {
-				fprintf(stderr, "%s: %s: size=%d/%d magic=%x/%x nr=%d nr2=%d types=%d,%d,%d/%d,%d,%d\n",
+				fprintf(stderr, "%s: %s: size=%d/%d magic=%x/%x nr=%d nr2=%d types=%u,%u,%u/%u,%u,%u\n",
 					__FUNCTION__, act[p]->name, act[p]->fsize, file_act.size,
 					act[p]->magic, file_act.magic, file_act.nr, file_act.nr2,
 					act[p]->gtypes_nr[0], act[p]->gtypes_nr[1], act[p]->gtypes_nr[2],
@@ -1018,7 +1038,7 @@ void read_stats_from_file(char from_file[])
 			  &file_actlst, id_seq, &endian_mismatch, &arch_64);
 
 	/* Perform required allocations */
-	allocate_structures(act);
+	allocate_structures(act, flags);
 
 	/* Print report header */
 	print_report_hdr(flags, &(rectime.tm_time), &file_hdr);
@@ -1050,7 +1070,7 @@ void read_stats_from_file(char from_file[])
 				 */
 				if (read_file_stat_bunch(act, 0, ifd, file_hdr.sa_act_nr,
 							 file_actlst, endian_mismatch, arch_64,
-							 from_file, &file_magic, UEOF_STOP))
+							 from_file, &file_magic, UEOF_STOP, flags))
 					/* Possible unexpected EOF */
 					return;
 
@@ -1141,7 +1161,7 @@ void read_stats_from_file(char from_file[])
 				if (rtype != R_COMMENT) {
 					if (read_file_stat_bunch(act, curr, ifd, file_hdr.sa_act_nr,
 								 file_actlst, endian_mismatch, arch_64,
-								 from_file, &file_magic, UEOF_STOP))
+								 from_file, &file_magic, UEOF_STOP, flags))
 						/* Possible unexpected EOF */
 						break;
 				}
@@ -1202,7 +1222,10 @@ void read_stats(void)
 	lines = rows = get_win_height();
 
 	/* Perform required allocations */
-	allocate_structures(act);
+	allocate_structures(act, flags);
+
+	/* No need to init min/max values. Already done in allocate_structures() */
+	xinit = FALSE;
 
 	/* Print report header */
 	print_report_hdr(flags, &(rectime.tm_time), &file_hdr);
@@ -1265,7 +1288,7 @@ void read_stats(void)
 		if (record_hdr[curr].record_type == R_LAST_STATS) {
 			/* File rotation is happening: Re-read header data sent by sadc */
 			read_header_data();
-			allocate_structures(act);
+			allocate_structures(act, flags);
 		}
 
 		if (count > 0) {
@@ -1372,6 +1395,11 @@ int main(int argc, char **argv)
 		}
 
 		else if (!strncmp(argv[opt], "--dec=", 6) && (strlen(argv[opt]) == 7)) {
+			/* Check that the argument is a digit */
+			if (!isdigit(argv[opt][6])) {
+				usage(argv[0]);
+			}
+
 			/* Get number of decimal places */
 			dplaces_nr = atoi(argv[opt] + 6);
 			if ((dplaces_nr < 0) || (dplaces_nr > 2)) {
